# Image display

Image display package is used to display the image continously.

## Installation

You can install the image display from [PyPI](https://pypi.org/project/imagedisplay/):

    pip install imagedisplay

## How to use

The imagedisplay is a command line application, named `imagedisplay`. To use simply call the program:

    $ python -m imagedisplay --image_path="path\to\image"